============
Installation
============

At the command line::

    $ easy_install hashedindex

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv hashedindex
    $ pip install hashedindex
